<!-- omit from toc -->
# bvhTools
**bvhTools** is a Python library to work with BVH (Biovision Hierarchy) files. It enables to load, modify and write BVH files in very few lines of code. This project is being developed in the context of a phD, so the library contains many BVH operations that I need to make often.

<!-- omit from toc -->
# 🌟 Functionalities
- Reading and writing BVH files
- Performing Forward Kinematics
- Manipulating BVH files (moving and rotating skeletons)
- BVH Slicing (partitioning and putting together motion data)
- BVH viewing using matplotlib
- Writing data to CSV files (world positions or  local positions + rotations)

# 📋 Documentation
The documentation to use this library can be found [here](https://enekoassets.github.io/bvhTools/).

# 🧰 Installation
To install and use **bvhTools**, just install it with pip.
```python
pip install bvhTools
```
The python package is still work in progress, so it may have some problems. In that case, you can open an issue on GitHub.